@@ -25,6 +25,8 @@
 
 G_BEGIN_DECLS
 
+/* NB: do NOT add new categories to the beginning or middle of this list.
+ * only add them to the end, right before XFCE_N_BUILTIN_ICON_CATEGORIES. */
 typedef enum { /*< prefix=XFCE_ICON_CATEGORY_ >*/
     XFCE_ICON_CATEGORY_UNKNOWN = 0,
     XFCE_ICON_CATEGORY_EDITOR,
@@ -44,6 +46,7 @@ typedef enum { /*< prefix=XFCE_ICON_CATEGORY_ >*/
     XFCE_ICON_CATEGORY_SETTINGS,
     XFCE_ICON_CATEGORY_SYSTEM,
     XFCE_ICON_CATEGORY_WINE,
+    XFCE_ICON_CATEGORY_ACCESSORIES,
     XFCE_N_BUILTIN_ICON_CATEGORIES
 } XfceIconThemeCategory;
 
