@@ -32,6 +32,8 @@
 #include <gtk/gtk.h>
 #include <string.h>
 
+#include "netk-private.h"
+
 #include <libxfcegui4/netk-trayicon.h>
 #include <libxfcegui4/xfce_systemtray.h>
 
@@ -52,30 +54,20 @@ static GObjectClass *parent_class;
 GType
 netk_tray_icon_get_type (void)
 {
-    static GType netk_tray_icon_type = 0;
+    static GType type = G_TYPE_INVALID;
 
-    if (!netk_tray_icon_type)
+    if (G_UNLIKELY (type == G_TYPE_INVALID))
     {
-        static const GTypeInfo netk_tray_icon_info = {
-            sizeof (NetkTrayIconClass),
-            NULL,		/* base_init */
-            NULL,		/* base_finalize */
-            (GClassInitFunc) netk_tray_icon_class_init,
-            NULL,		/* class_finalize */
-            NULL,		/* class_data */
-            sizeof (NetkTrayIcon),
-            0,			/* n_preallocs */
-            (GInstanceInitFunc) netk_tray_icon_init,
-            NULL		/* value_table */
-        };
-
-        netk_tray_icon_type = g_type_register_static (GTK_TYPE_PLUG,
-                                                      "NetkTrayIcon",
-                                                      &netk_tray_icon_info,
-                                                      0);
+        type = _netk_g_type_register_simple (GTK_TYPE_PLUG,
+                                             "NetkTrayIcon",
+                                             sizeof (NetkTrayIconClass),
+                                             netk_tray_icon_class_init,
+                                             sizeof (NetkTrayIcon),
+                                             netk_tray_icon_init,
+                                             0);
     }
 
-    return (netk_tray_icon_type);
+    return type;
 }
 
 static void
