@@ -1,7 +1,7 @@
-/* $Id: xfce-gdk-extensions.c 1506 2004-09-26 23:04:06Z kelnos $ */
+/* $Id: xfce-gdk-extensions.c 21491 2006-05-04 21:23:29Z benny $ */
 /*-
- * Copyright (c) 2003 Mark McLoughlin <mark@skynet.ie>
- * Copyright (c) 2004 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003      Mark McLoughlin <mark@skynet.ie>
+ * Copyright (c) 2004-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -34,10 +34,9 @@
 #include <X11/Xlib.h>
 
 #include <gdk/gdkx.h>
-#include <gtk/gtk.h>
 
-#include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/xfce-gdk-extensions.h>
+#include <libxfcegui4/libxfcegui4.h>
+
 
 
 /**
@@ -92,6 +91,7 @@ xfce_gdk_display_get_fullname (GdkDisplay *display)
 }
 
 
+
 static gboolean
 screen_contains_pointer (GdkScreen *screen,
                          int       *x,
@@ -120,6 +120,7 @@ screen_contains_pointer (GdkScreen *screen,
 }
 
 
+
 /**
  * xfce_gdk_display_locate_monitor_with_pointer:
  * @display        : A Gdk display or %NULL to choose the default display.
@@ -166,6 +167,7 @@ xfce_gdk_display_locate_monitor_with_pointer (GdkDisplay *display,
 }
 
 
+
 /**
  * xfce_gdk_screen_get_fullname:
  * @screen : A Gdk screen.
@@ -196,46 +198,6 @@ xfce_gdk_screen_get_fullname (GdkScreen *screen)
 }
 
 
-#if !GTK_CHECK_VERSION(2, 4, 0)
-static gchar **
-xfce_gdk_spawn_make_environment_for_screen (GdkScreen  *screen,
-                                            gchar     **envp)
-{
-  extern char **environ;
-
-  gchar **retval = NULL;
-  gchar  *display_name;
-  gint    display_index = -1;
-  gint    i, env_len;
-
-  g_return_val_if_fail (GDK_IS_SCREEN (screen), NULL);
-
-  if (envp == NULL)
-    envp = environ;
-
-  for (env_len = 0; envp[env_len]; env_len++)
-    if (strncmp (envp[env_len], "DISPLAY", strlen ("DISPLAY")) == 0)
-      display_index = env_len;
-
-  retval = g_new (char *, env_len + 1);
-  retval[env_len] = NULL;
-
-  display_name = gdk_screen_make_display_name (screen);
-
-  for (i = 0; i < env_len; i++)
-    if (i == display_index)
-      retval[i] = g_strconcat ("DISPLAY=", display_name, NULL);
-    else
-      retval[i] = g_strdup (envp[i]);
-
-  g_assert (i == env_len);
-
-  g_free (display_name);
-
-  return retval;
-}
-#endif
-
 
 /**
  * xfce_gdk_spawn_on_screen:
@@ -272,29 +234,13 @@ xfce_gdk_spawn_on_screen (GdkScreen           *screen,
                           gint                *child_pid,
                           GError             **error)
 {
-#if GTK_CHECK_VERSION(2,4,0)
   return gdk_spawn_on_screen (screen, working_directory, argv, envp,
                               flags, child_setup, user_data, child_pid,
                               error);
-#else
-  gchar   **new_envp;
-  gboolean  retval;
-
-  g_return_val_if_fail (GDK_IS_SCREEN (screen), FALSE);
-
-  new_envp = xfce_gdk_spawn_make_environment_for_screen (screen, envp);
-  
-  retval = g_spawn_async (working_directory, argv, new_envp,
-                          flags, child_setup, user_data,
-                          child_pid, error);
-
-  g_strfreev (new_envp);
-
-  return retval;
-#endif
 }
 
 
+
 /**
  * xfce_gdk_spawn_on_screen_with_pipes:
  * @screen            : a #GdkScreen
@@ -340,39 +286,15 @@ xfce_gdk_spawn_on_screen_with_pipes (GdkScreen            *screen,
                                      gint                 *standard_error,
                                      GError              **error)
 {
-#if GTK_CHECK_VERSION(2,4,0)
   return gdk_spawn_on_screen_with_pipes (screen, working_directory,
                                          argv, envp, flags, child_setup,
                                          user_data, child_pid, standard_input,
                                          standard_output, standard_error,
                                          error);
-#else
-  gchar    **new_envp;
-  gboolean   retval;
-
-  g_return_val_if_fail (GDK_IS_SCREEN (screen), FALSE);
-
-  new_envp = xfce_gdk_spawn_make_environment_for_screen (screen, envp);
-
-  retval = g_spawn_async_with_pipes (working_directory,
-				                             argv,
-                                     new_envp,
-                                     flags,
-                                     child_setup,
-                                     user_data,
-                                     child_pid,
-                                     standard_input,
-                                     standard_output,
-                                     standard_error,
-                                     error);
-
-  g_strfreev (new_envp);
-
-  return retval;
-#endif
 }
 
 
+
 /**
  * xfce_gdk_spawn_command_line_on_screen:
  * @screen       : a #GdkScreen
@@ -396,25 +318,5 @@ xfce_gdk_spawn_command_line_on_screen (GdkScreen    *screen,
 				                               const gchar  *command_line,
                               				 GError      **error)
 {
-#if GTK_CHECK_VERSION(2,4,0)
   return gdk_spawn_command_line_on_screen (screen, command_line, error);
-#else
-  gchar   **argv = NULL;
-  gboolean  retval;
-
-  g_return_val_if_fail (command_line != NULL, FALSE);
-
-  if (!g_shell_parse_argv (command_line, NULL, &argv, error))
-    return FALSE;
-
-  retval = xfce_gdk_spawn_on_screen (screen,
-                                     NULL, argv, NULL,
-                        				     G_SPAWN_SEARCH_PATH,
-                        				     NULL, NULL, NULL,
-                        				     error);
-
-  g_strfreev (argv);
-
-  return retval;
-#endif
 }
