@@ -259,23 +259,17 @@ xfce_system_tray_register (XfceSystemTray * tray, Screen * xscreen,
     Window rootwin;
     guint32 timestamp;
     GtkWidget *window;
-#if defined (GTK_CHECK_VERSION) && GTK_CHECK_VERSION(2,2,0)
     GdkScreen *screen;
-#endif
 
     display = DisplayOfScreen (xscreen);
     /*
      * Clients must use a window they created so that requestors can
      * route events to the owner of the selection.
      */
-#if defined (GTK_CHECK_VERSION) && GTK_CHECK_VERSION(2,2,0)
     screen =
         gdk_display_get_screen (gdk_x11_lookup_xdisplay (display),
                                 XScreenNumberOfScreen (xscreen));
     window = gtk_invisible_new_for_screen (screen);
-#else
-    window = gtk_invisible_new ();
-#endif
     gtk_widget_realize (window);
     gtk_widget_add_events (window,
                            GDK_PROPERTY_CHANGE_MASK | GDK_STRUCTURE_MASK);
@@ -431,10 +425,19 @@ xfce_system_tray_dock_request (XClientMessageEvent * xev,
     GtkRequisition req;
 #endif
 
-    if (g_hash_table_lookup (tray->sockets, GINT_TO_POINTER (xev->data.l[2])))
+    icon = GTK_WIDGET (g_hash_table_lookup (tray->sockets, GINT_TO_POINTER (xev->data.l[2])));
+    if (icon)
     {
-        /* We already got this notification earlier, ignore this one */
-        return;
+        /*
+         * We used to simply ignore the request if a socket was already present,
+         * but that seems to confuse some KDE apps like krusader.
+         * Instead, remove the existing icon and let the process create a new one,
+         * it seems it works just fine. Might not be totally standard, I don't 
+         * know.
+         */
+
+        g_hash_table_remove (tray->sockets, GINT_TO_POINTER (xev->data.l[2]));
+        gtk_widget_destroy (icon);
     }
 
     xwindow = g_new (Window, 1);
